Finds \(\mathrm{argmin}_{p\in M}\sum_{i=1} ^ {N} \rho(d(p,y_i))\) through a gradient descent algorithm.
intrinsic_location(
manifold,
y,
estimator,
c = NULL,
p_tol = 1e-05,
V_tol = 1e-05,
max_iter = 1e+05
)Type of manifold ('euclidean', 'sphere',
'hyperbolic', or 'kendall').
A matrix or data frame whose columns represent points on the manifold.
M-type estimator ('l2', 'l1', 'huber',
or 'tukey').
Multiplier of \(\sigma\), the square root of the variance, used in
the cutoff parameter for the 'huber' and 'tukey' estimators;
should be NULL for the 'l2' or 'l1' estimators.
Termination condition for the distance between consecutive
updates of p.
Termination condition for the distance between columns of
consecutive updates of V, parallel transported to be in the same
tangent space. Can be a vector of positive real numbers for each
independent variable or a single positive number.
Maximum number of gradient descent steps before ending the algorithm.
A vector representing the location estimate
In the case of the 'sphere', an error will be raised if all points are
on a pair of antipodes.
Fletcher, P. T. (2013). Geodesic regression and the theory of least squares on Riemannian manifolds. International Journal of Computer Vision, 105, 171-185.
Kim, H. J., Adluru, N., Collins, M. D., Chung, M. K., Bendin, B. B., Johnson, S. C., Davidson, R. J. and Singh, V. (2014). Multivariate general linear models (MGLM) on Riemannian manifolds with applications to statistical analysis of diffusion weighted images. 2014 IEEE Conference on Computer Vision and Pattern Recognition, 2705-2712.
Shin, H.-Y. and Oh H.-S. (2020). Robust Geodesic Regression. <arXiv:2007.04518>
# NOT RUN {
y <- matrix(runif(100, 1000, 2000), nrow = 10)
intrinsic_location('euclidean', y, 'l2')
# }
Run the code above in your browser using DataLab