Learn R Programming

GeodRegr (version 0.2.0)

rnormtangents: Random generation of tangent vectors from the Riemannian normal distribution

Description

Random generation of tangent vectors from the Riemannian normal distribution on the n-dimensional sphere or hyperbolic space at mean (1, 0, ..., 0), a vector of length n+1.

Usage

rnormtangents(manifold, N, n, sigma_sq)

Arguments

manifold

Type of manifold ('sphere' or 'hyperbolic').

N

Number of points to generate.

n

Dimension of the manifold.

sigma_sq

A scale parameter.

Value

An (n+1)-by-N matrix where each column represents a random tangent vector at (1, 0, ..., 0).

Details

Tangent vectors are of the form \(\mathrm{Log}(\mu, y)\) in the tangent space at the Fr\'echet mean \(\mu\) = (1, 0, ..., 0), which is isomorphic to n-dimensional Euclidean space, where \(y\) has a Riemannian normal distribution. The first element of these vectors will always be 0 at this \(\mu\). These vectors can be transported to any other \(\mu\) on the manifold.

References

Fletcher, P. T. (2013). Geodesic regression and the theory of least squares on Riemannian manifolds. International Journal of Computer Vision, 105, 171-185.

Fletcher, T. (2020). Statistics on manifolds. In Riemannian Geometric Statistics in Medical Image Analysis. 39--74. Academic Press.

Shin, H.-Y. and Oh H.-S. (2020). Robust Geodesic Regression. <arXiv:2007.04518>

Examples

Run this code
# NOT RUN {
sims <- rnormtangents('hyperbolic', N = 4, n = 2, sigma_sq = 1)

# }

Run the code above in your browser using DataLab